@@ -14,6 +14,7 @@
  * limitations under the License.
  */
 
+#include "globus_i_xio_config.h"
 #include "globus_xio_driver.h"
 #include "globus_xio_tcp_driver.h"
 #include "version.h"
@@ -21,18 +22,11 @@
 #include <netinet/tcp.h>
 #endif
 
-#ifdef WIN32
+#if defined(_WIN32) && !defined(EADDRINUSE)
 #define EADDRINUSE              WSAEADDRINUSE
 #endif
 
-#ifdef HAVE_SOCKAPI_H
-#include <sockapi.h>
-#define SOMAXCONN 5
-#endif
-
-#ifndef TARGET_ARCH_NETOS
 #include <fcntl.h>
-#endif
 
 GlobusDebugDefine(GLOBUS_XIO_TCP);
 
